@@ -155,11 +155,6 @@ typedef struct opkg_conf {
      */
     char *http_auth;
 
-    /* pathfinder options: used only when opkg is configured with
-     * '--enable-pathfinder', otherwise always NULL or 0 as above.
-     */
-    int check_x509_path;
-
     /* proxy options */
     char *http_proxy;
     char *https_proxy;
@@ -168,12 +163,10 @@ typedef struct opkg_conf {
     char *proxy_user;
     char *proxy_passwd;
 
-    char *signature_ca_file;
-    char *signature_ca_path;
-
     hash_table_t pkg_hash;
     hash_table_t file_hash;
     hash_table_t obs_file_hash;
+    hash_table_t dir_hash;
 } opkg_conf_t;
 
 enum opkg_option_type {
